@@ -14,7 +14,7 @@ import os
 
 from pgadmin.utils.route import BaseTestGenerator
 from regression import parent_node_dict
-from pgadmin.utils import server_utils as server_utils, is_utility_exists
+from pgadmin.utils import server_utils as server_utils, does_utility_exist
 from pgadmin.browser.server_groups.servers.databases.tests import utils as \
     database_utils
 
@@ -653,7 +653,11 @@ class BackupCreateJobTest(BaseTestGenerator):
         binary_path = os.path.join(
             self.server['default_binary_paths'][self.server['type']],
             'pg_dump')
-        retVal = is_utility_exists(binary_path)
+
+        if os.name == 'nt':
+            binary_path = binary_path + '.exe'
+
+        retVal = does_utility_exist(binary_path)
         if retVal is not None:
             self.skipTest(retVal)
 
